package com.ruoyi.powerdistribution.mapper;

import java.util.List;
import com.ruoyi.powerdistribution.domain.PdmBranchLine;
import com.ruoyi.powerdistribution.domain.vo.PdmBranchLineComplete;

/**
 * 可靠性分支线Mapper接口
 *
 * @author ruoyi
 * @date 2024-12-24
 */
public interface PdmBranchLineMapper
{
    /**
     * 查询可靠性分支线
     *
     * @param id 可靠性分支线主键
     * @return 可靠性分支线
     */
    public PdmBranchLine selectPdmBranchLineById(Long id);

    /**
     * 查询可靠性分支线列表
     *
     * @param pdmBranchLine 可靠性分支线
     * @return 可靠性分支线集合
     */
    public List<PdmBranchLine> selectPdmBranchLineList(PdmBranchLine pdmBranchLine);

    /**
     * 新增可靠性分支线
     *
     * @param pdmBranchLine 可靠性分支线
     * @return 结果
     */
    public int insertPdmBranchLine(PdmBranchLine pdmBranchLine);

    /**
     * 修改可靠性分支线
     *
     * @param pdmBranchLine 可靠性分支线
     * @return 结果
     */
    public int updatePdmBranchLine(PdmBranchLine pdmBranchLine);

    /**
     * 删除可靠性分支线
     *
     * @param id 可靠性分支线主键
     * @return 结果
     */
    public int deletePdmBranchLineById(Long id);

    /**
     * 批量删除可靠性分支线
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePdmBranchLineByIds(Long[] ids);

    /**
     * 查询分支线完成情况
     * @param complete
     * @return
     */
    List<PdmBranchLineComplete> selectBranchLineCompleteList(PdmBranchLineComplete complete);
}
